# Code for analysis of Chakarov et al . "Variation at phenological candidate genes correlates with timing of dispersal and plumage morph in a sedentary bird of prey"
rm(list=ls())
setwd("C:/Users/Downloads")
library(lme4)

broods  <- read.table("broods.csv", header=TRUE, sep=",")
nestlings   <- read.table("nestlings.csv",  header=TRUE, sep=",")
resighted   <- read.table("resighted.csv",  header=TRUE, sep=",") # resighted individuals
disp   <- read.table("dispersers.csv",  header=TRUE, sep=",") # dataset of individuals resighted more than 20 km away from their natal nest before November 1 (latedispersal=0) or less than 10 km away after November 1 (latedispersal=1)
    
#Models for individual parental effects on brood fledging date

broods$mid<-as.factor(broods$male_id) # mid - Male parent ID as factor
broods$fid<-as.factor(broods$fem_id) # fid - female parent ID as factor
broods$fm<-as.factor(broods$fm) # fm - Female parent's Morph
#str(broods)
model1<-lmer(fledge_stand~fm+(1|y), broods, REML=FALSE)  # fledge_stand - standardised fledging date - our measure of timing
model2<-lmer(fledge_stand~fm+(1|fid)+(1|y), broods, REML=FALSE)       #y is year
anova(model1, model2, test="Chi") # significance of female ID on standarddised fledging date
summary(model1)
model2REML<-lmer(fledge_stand~fm+(1|fid)+(1|y), broods, REML=TRUE)
summary(model2REML)
0.34559/(0.34559+0.65061) # Individual repeatability of standardised fledging date for individual females.
model3_Mal_idPlusFem_id<-lmer(fledge_stand~fm+(1|fid)+(1|mid), broods)
summary(model3_Mal_idPlusFem_id) # Effect sizes of timing under the effect of female ID combined with male ID
model4<-lmer(fledge_stand~fm+(1|fid), broods) 
summary(model4)
# repeatability fid:
0.34559/(0.34559+0.65061) 
anova(model4,model2)   # this shows that year should not be in random effect, as can be expected since standardisation controls for it already   
anova(model3_Mal_idPlusFem_id, model4, test="Chi") # significance of male ID on standardised brood timing
# this tells that model with female and and male ID is best.
model2REML<-lmer(fledge_stand~fm+(1|fid)+(1|mid), broods, REML=FALSE)
0.15226/(0.15226+0.23566+0.61308)  # repeatability for males
0.23566/(0.15226+0.23566+0.61308)  # repeatability for females
model2REMLnoMorph<-lmer(fledge_stand~1+(1|fid)+(1|mid), broods, REML=FALSE)
anova(model2REML, model2REMLnoMorph, test="Chi") # significance of effect of female morph on standardised brood timing
summary(model2REML)




# Models for explanatory potential of nestling mean allele length to brood fledging date

nestlings$fst<-nestlings$fledge_date_standardised # Standardised mean fledging date of brood, identical for broodmates
nestlings$ame<-nestlings$adcyap1_mean #ADCYAP1 mean allele length of nestling
nestlings$np<-nestlings$npas2_170 #binomial variable for NPAS2 167/167 or 167/170
nestlings$cmean<-nestlings$creb1_mean # CREB1 mean allele length of nestling
nestlings$fm<-as.factor(nestlings$fem_mor) #morph of nestling's mother
nestlings$cm<-as.factor(nestlings$chick_mor) # nestling's own morph


str(nestlings)
names(nestlings)  

nestlings1<-subset(nestlings, adcyap1_mean>-1) # subset for individuals genotyped for ADCYAP1
model_MeanADCYAP_FemaleID <-lmer(fst~ame+(1|fid), nestlings1, gaussian) 
summary(model_MeanADCYAP_FemaleID)# not executable to bid because fst (brood fledging date) identical to all members of brood
model_Int_FemaleID        <-lmer(fst~1+(1|fid), nestlings1, gaussian)
summary(model_Int_FemaleID)
anova(model_Int_FemaleID, model_MeanADCYAP_FemaleID, test="Chi") # significance for mean ADCYAP1 allele length of nestling

nestlings2<-subset(nestlings1, np>-1) # dataset with available NPAS2
model_int_nestlings2   <-lmer(fst~1+(1|fid), nestlings2, gaussian)
model_NPAS_nestlings2  <-lmer(fst~np+(1|fid), nestlings2, gaussian)
anova(model_int_nestlings2, model_NPAS_nestlings2, test="Chi") # significance for mean NPAS2 allele length of nestling
nestlings3<-subset(nestlings2, cmean>-100) # dataset for nestlings genotyped for CREB1, nestlings3$cmean - mean length of CREB1 for nestling
model_int_fz4<-lmer(fst~1+(1|fid), nestlings3, gaussian)
model_CREB1_fz4<-lmer(fst~cmean+(1|fid), nestlings3, gaussian)
anova(model_int_fz4, model_CREB1_fz4, test="Chi") # significance for mean CREB1 allele length of nestling on fledging date


#Models for effects of candidate genes on probablity of being resighted


str(nestlings)          
# dataset nestlings; nestlings$resighted: binomial variable 0-not resighted, 1- resighted; nestlings$rtarsus - size of nestling relative to broodmates, rtarsus is a measure of brood hierarchy which is not subject of the paper but is important and controlled for. 

nestlings2m<-subset(nestlings2, chick_mor>1) # subset of nestlings for which morph has been scored
model_NPASandMorphCorrForHierarchy    <-lmer(resighted~np+rtarsus+cm+(1|bid)+(1|fid)+(1|year), nestlings2m, binomial)
model_NPASandMorph    <-lmer(resighted~np+cm+(1|bid)+(1|fid)+(1|year), nestlings2m, binomial) 
model_CorrForHierarchyAndMorph        <-lmer(resighted~rtarsus+cm+(1|bid)+(1|fid)+(1|year), nestlings2m, binomial)
anova(model_NPASandMorphCorrForHierarchy, model_CorrForHierarchyAndMorph, test="Chi") # effect of NPAS2 allele length on probabilty of being resighted
model_CorrForHierarchyAndNPAS         <-lmer(resighted~np+rtarsus+(1|bid)+(1|fid)+(1|year), nestlings2m, binomial) 
anova(model_NPASandMorphCorrForHierarchy, model_CorrForHierarchyAndNPAS, test="Chi") # test for morph
summary(model_NPASandMorphCorrForHierarchy)
anova(model_NPASandMorphCorrForHierarchy, model_NPASandMorph)         # test for hierarchy importance

model_ADCmeanCorrForHierarchy<-lmer(resighted~adcyap1_mean+rtarsus+(1|bid)+(1|fid)+(1|year), nestlings2m, binomial)
model_CorrForHierarchy<-lmer(resighted~rtarsus+(1|bid)+(1|fid)+(1|year), nestlings2m, binomial)
anova(model_ADCmeanCorrForHierarchy, model_CorrForHierarchy, test="Chi") # no effect of ADCYAP1
summary(model_ADCmeanCorrForHierarchy)

model_CmeanCorrForHierarchy<-lmer(resighted~cmean+rtarsus+(1|bid)+(1|fid)+(1|year), nestlings3, binomial)
model_CorrForHierarchy<-lmer(resighted~rtarsus+(1|bid)+(1|fid)+(1|year), nestlings3, binomial)
anova(model_CmeanCorrForHierarchy, model_CorrForHierarchy, test="Chi") # no effect of CREB1
summary(  model_CmeanCorrForHierarchy)
#

# Models explaining distance from natal nest at first resighting irrespective of time past

str(resighted)        # max n = 160
#resighted - dataset 
#resighted$dist_a - distance from nest in km
#resighted$adl - mean ADCYAP1 length of individual
#resighted$np17 - presence of NPAS2 allele 170 in individual or not
#resighted$cr53 - presence of CREB1 allele 535 in individual or not
resighted$ldi<-log(resighted$dist_a+1)

model_ADCYAPandNPAS_onLogDispersal        <-lmer(ldi~np17+adl+(1|bid), resighted, gaussian, REML=FALSE) 
model_NPAS_onLogDispersal                 <-lmer(ldi~np17+(1|bid), resighted, gaussian, REML=FALSE)
summary(model_ADCYAPandNPAS_onLogDispersal)
anova(model_ADCYAPandNPAS_onLogDispersal, model_NPAS_onLogDispersal, test="f")             # no effect of mean ADCYAP1 length on distance of dispersal
model_ADCYAP_onLogDispersal               <-lmer(ldi~adl+(1|bid), resighted, gaussian, REML=FALSE)
model_Int_onLogDispersal                  <-lmer(ldi~1+(1|bid), resighted, gaussian, REML=FALSE)
anova(model_NPAS_onLogDispersal, model_Int_onLogDispersal, test="f")
summary(model_NPAS_onLogDispersal)             # effect of NPAS2 on distance of dispersal

resighted1<-subset(resighted, cr535>-1)                # subset of individuals genotyped for CREB1
model_NPAS_onLogDispersal_CrebData        <-lmer(ldi~np17+(1|bid), resighted1, gaussian, REML=FALSE)
model_CrebAndNPAS_onLogDispersal_CrebData <-lmer(ldi~np17+cr53+(1|bid), resighted1, gaussian, REML=FALSE)
anova(model_NPAS_onLogDispersal_CrebData, model_CrebAndNPAS_onLogDispersal_CrebData, test="f")           # no effect of CREB1 on distance of dispersal
summary(model_CrebAndNPAS_onLogDispersal_CrebData)




# Models explaining probablity to be seen within 10 km of nest after November 1 or further away before that

#dataset disp; disp$latedispersal - binomial variable: 0 - early/normal dispersers, 1- late/non-dispersers
# disp$cm - morph of the individual
str(disp)
disp$maleid<-as.factor(disp$maleid) # mid - Male parent ID as factor
disp$femid<-as.factor(disp$femid) # fid - female parent ID as factor
disp$femmor<-as.factor(disp$femmor) 
disp$malemor<-as.factor(disp$malemor) 
disp$chickmor<-as.factor(disp$chickmor)
disp$cm<-as.factor(disp$cm) 

model_Dispersal_Int<-lmer(latedispersal~1+(1|year), disp, binomial)     
model_Dispersal_ChickMorph<-lmer(latedispersal~chickmor+(1|year), disp, binomial)
anova(model_Dispersal_Int, model_Dispersal_ChickMorph, test="Chi") # effect of morph on dispersal
summary(model_Dispersal_ChickMorph)      
disp1<-subset(disp, adlen>-1) # subset of individuals genotyped for ADCYAP1   
#disp1$adlen - mean ADCYAP1 allele length of individual
#disp1$cr535 - CREB1 allele 535 present in individual (1 - yes, mean allele length 534; 0 - no, 535) 

model_AcdyapData_Dispersal_Int    <-lmer(latedispersal~1+(1|year), disp1, binomial)
model_AcdyapData_Dispersal_Adcyap <-lmer(latedispersal~adlen+(1|year), disp1, binomial)
anova(model_AcdyapData_Dispersal_Int, model_AcdyapData_Dispersal_Adcyap, test="Chi") # effect of ADCYAP1 length on dispersal
summary(model_AcdyapData_Dispersal_Adcyap)

disp2<-subset(disp1, cr535>-1) # subset of individuals genotyped for CREB1
model_CrebData_Dispersal_AdcyapAndCreb  <-lmer(latedispersal~adlen+cr535+(1|year), disp2, binomial)
model_CrebData_Dispersal_AdcyapOnly     <-lmer(latedispersal~adlen+(1|year), disp2, binomial)
anova(model_CrebData_Dispersal_AdcyapAndCreb, model_CrebData_Dispersal_AdcyapOnly, test="Chi") # effect of CREB1 on dispersal 
summary(model_CrebData_Dispersal_AdcyapAndCreb)